@@ -2,8 +2,8 @@ from __future__ import division
 import numpy
 import scipy
 import networkx
-import FARZ
-from extended_models import *
+from FARZ import *
+from models import *
 
 import matplotlib.pyplot as pyplot
 
